# iicd-workshop-2024

[![pypi](https://img.shields.io/pypi/v/iicd-workshop-2024)](https://pypi.org/project/iicd-workshop-2024/)
[![Build status](https://img.shields.io/github/actions/workflow/status/anazaret/iicd-workshop-2024/main.yml?branch=main)](https://github.com/anazaret/iicd-workshop-2024/actions/workflows/main.yml?query=branch%3Amain)
[![Commit activity](https://img.shields.io/github/commit-activity/m/anazaret/iicd-workshop-2024)](https://img.shields.io/github/commit-activity/m/anazaret/iicd-workshop-2024)
[![License](https://img.shields.io/github/license/anazaret/iicd-workshop-2024)](https://img.shields.io/github/license/anazaret/iicd-workshop-2024)

Code accompanying the iicd workshop 2024

- **Documentation** <https://anazaret.github.io/iicd-workshop-2024/>
